<p align="center">
  <a href="https://mathy.ai"><img mathy-logo src="https://mathy.ai/img/mathy_logo.png" alt="Mathy.ai"></a>
</p>
<p align="center">
    <em>A modern platform for combining machine learning with interpretable symbolic mathematics.</em>
</p>
<p align="center">
<a href="https://github.com/justindujardin/mathy/actions">
    <img src="https://github.com/justindujardin/mathy/workflows/Build/badge.svg" />
</a>
<a href="https://codecov.io/gh/justindujardin/mathy">
    <img src="https://codecov.io/gh/justindujardin/mathy/branch/master/graph/badge.svg?token=CqPEOdEMJX" />
</a>
<a href="https://pypi.org/project/mathy" target="_blank">
    <img src="https://badge.fury.io/py/mathy.svg" alt="Package version">
</a>
<a href="https://gitter.im/justindujardin/mathy?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge" target="_blank">
    <img src="https://badges.gitter.im/justindujardin/mathy.svg" alt="Join the chat at https://gitter.im/justindujardin/mathy">
</a>
</p>


## Website

Mathy's website has rich documentation with visualizations and examples that can be directly executed in Google Colab: <a href="https://mathy.ai" target="_blank">https://mathy.ai</a>

## Contributors

Mathy wouldn't be possible without the wonderful contributions of the following people:

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a target="_blank" href="https://www.justindujardin.com/"><img src="https://avatars0.githubusercontent.com/u/101493?v=4" width="100px;" alt=""/><br /><sub><b>Justin DuJardin</b></sub></a></td>
  </tr>
</table>

<!-- markdownlint-enable -->
<!-- prettier-ignore-end -->
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
